@@ -46,3 +46,12 @@ class OnAppStartSignal(Signal):
     """
     pass
 
+
+@singleton
+class OnLackOfNecessaryPlugin(Signal):
+    """
+    应用缺少必要插件时的信号
+    """
+    def dispatch(self, plugin_tye):
+        super().dispatch(plugin_tye)
+
